@@ -44,6 +44,8 @@ ssl_cert_parameter_map = {
 }
 
 
+
+
 def _parse_timestamp(value):
     if value:
         match = _TIMESTAMP_PATTERN.match(value)
@@ -196,7 +198,7 @@ class Cursor(common.DBAPICursor):
     Cursors are not isolated, i.e., any changes done to the database by a cursor are immediately
     visible by other cursors or connections.
     """
-
+    rows_count = 0
     def __init__(self, connection, arraysize=1000):
         super(Cursor, self).__init__()
         self._arraysize = arraysize
@@ -329,13 +331,17 @@ class Cursor(common.DBAPICursor):
         return self._fetch_all()
 
     def fetchone(self):
+
         _logger.info("fetching one")
         if len(self._batch) == 0:
             self.fetch_batch()
             if len(self._batch) == 0:
                 return None
-
-        row = self._batch.pop()
+        self.rows_count += len(self._batch)
+        if self.rows_count <= 1000:
+            row = self._batch.pop()
+        else:
+            row = None
         return row
 
     # def fetchone(self):
@@ -376,11 +382,11 @@ class Error(Exception):
 
 
 if __name__ == '__main__':
-    connection = connect(host="54.237.240.43",
+    connection = connect(host="44.203.152.210",
                          port=9000,
                          scheme="e6xdb",
                          username="admin",
-                         database="./input/tpcds_330mb",
+                         database="s3a://e6-tpcds/parquet100gb_128/",
                          auth=None,
                          configuration=None,
                          kerberos_service_name=None,
@@ -389,7 +395,7 @@ if __name__ == '__main__':
                          ssl_cert=None,
                          thrift_transport=None)
     cursor = Cursor(connection)
-    cursor.execute("SELECT dd.d_year FROM store_returns sr INNER JOIN date_dim dd ON sr.sr_returned_date_sk = dd.d_date_sk order by dd.d_year limit 10")
+    cursor.execute("SELECT sr_returned_date_sk,sr_return_time_sk,sr_item_sk,sr_customer_sk,sr_cdemo_sk,sr_hdemo_sk,sr_addr_sk FROM store_returns WHERE sr_hdemo_sk >= 2000 AND sr_hdemo_sk < 2000 + 1;")
     bdata = cursor.fetchone()
     try:
         while bdata:
